@@ -3,7 +3,7 @@ package Database::Async::Query;
 use strict;
 use warnings;
 
-our $VERSION = '0.017'; # VERSION
+our $VERSION = '0.018'; # VERSION
 
 =head1 NAME
 
@@ -318,7 +318,7 @@ Schedules this query for execution.
 
 sub start {
     my ($self) = @_;
-    $self->{queued} //= $self->db->queue_query($self)->retain;
+    $self->{queued} //= $self->db->queue_query($self);
 }
 
 sub run_on {
@@ -458,5 +458,5 @@ Tom Molesworth C<< <TEAM@cpan.org> >>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2011-2021. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2011-2023. Licensed under the same terms as Perl itself.
 
